%--------------------------------------------------------------------------
% This script takes in all data sets and calculates the time-lagged 
% correlation-coefficients.
%--------------------------------------------------------------------------
load amplitude12.mat    %Import the 12-hour amplitude
amp12 = x12;            
load amplitude24.mat    %Import the 12-hour amplitude
amp24 = x24;                
load amplitude12_24.mat %Import the 12-hour amplitude
amp12_24 = x12_24;      
load amplitude8.mat
amp8=x8;
load amplitude48.mat
amp48=x48;
load AEindex            %Import the AE-index
AE = VarName29;
load NO2008                 %Import the NO-concentration    
NO = NO';           
load VMR2008                %Import the NO-vmr
VMR = vmr;              
load MEPmean            %Load the EPP (MEP)-data
MEP = MEP(:,2);         

%--------------------------------------------------------------------------
% Uncomment to choose which data to correlate and set Interval-length I
%--------------------------------------------------------------------------
I=50:176;  % The length of usable wind-data
%I=50:366;  % The length of usable NO-data


%yy=amp8(I);
%yy=amp48(I);
%yy=amp24(I);
%yy=amp12(I);
%yy=amp12_24(I);
%yy = (amp24(I).*AE(I))';
yy = (amp12(I).*AE(I))';
%yy = (amp12_24(I).*AE(I))';
%yy = AE(I); 
%yy = MEP(I);

%yy1 = VMR(I)'; %NO-vmr
yy1 = NO(I);   %NO-concentration
nlags=50;  

% % figure(1)
% % %subplot(2,1,1)
% % [AX,H1,H2]=plotyy(I,yy,I,yy1,'plot');
% % %hold on
% % %plot(I,yy1/max(yy1))
% % title('')
% % %hold off
% % set(get(AX(2),'Ylabel'),'String','NO concentration (molecules/cm^2');%yy1 label
% % set(get(AX(1),'Ylabel'),'String','sum of 12 and 24-hour wind modulated by AE (nT m / s)'); %yy1 label
% % xlabel('Day of year')
figure(2)
out=zeros(2*nlags+1,1);
p=zeros(2*nlags+1,1);
RL=zeros(2*nlags+1,1);
RU=zeros(2*nlags+1,1);
% first the negative lags, where we use corrcoef 'rows' with either 'complete' or
%'pairwise' (for just 2 columns it does not matter) to eliminate any NaN's
% in the correlation. Pearson's linear correlation coefficient. With
% corrcoef we can also calculate the probability and upper and lower
% confidence bounds for alpha = 0.05 -> 95% confidence

for i=nlags+1:-1:2
    [cccoef, ppp, cclow, ccup ]= corrcoef(yy(i:end),yy1(1:end-i+1),'alpha',0.05,'rows','pairwise');
    out(nlags+2-i)=cccoef(2,1);
    p(nlags+2-i)=ppp(2,1);   % P-values for result
    RL(nlags+2-i)=ccup(2,1); % Lower limit for confidence interval  
    RU(nlags+2-i)=cclow(2,1);% Upper limit for confidence interval
end
%then the positive lags
for i=1:nlags+1
    [cccoef, ppp, cclow, ccup ]= corrcoef(yy1(i:end),yy(1:end-i+1),'alpha',0.05,'rows','pairwise');
    out(i+nlags)=cccoef(2,1); 
    p(i+nlags)=ppp(2,1); 
    RL(i+nlags)=ccup(2,1); 
    RU(i+nlags)=cclow(2,1);
end

% Positive correlation coeficcient (right hand side) means that the other
% data is leading the NO.

plot(-nlags:nlags,out,'b')
title('Correlation analysis between 24 Hour wind amplitudes and NO volume mixing ratio.')
hold on;
plot(-nlags:0.2:nlags,0,'r') %to make a line at zero
plot(0,-1:0.01:1,'r') %to make a divide
plot(-nlags:0.01:nlags,0.3,'g')
%plot(-nlags:0.01:nlags,0.6,'y')
plot(-nlags:nlags,RU,':b') 
plot(-nlags:nlags,RL,':b')
xlabel('Number of days NO values is lagged relative to Wind amplitudes')
ylabel('Correlation coefficient')


