%--------------------------------------------------------------------------
% Extracting data for the volume mixing ratio of NO for 2008
%--------------------------------------------------------------------------
NO2008 = load('MR_NO250GHz_2008all_0000-2400_fr5f_negativevmr.ppmv');
% Load needed values for finding the number of NO particles

% Define the range of heights and amount of days from the data
length_year=366; %Number of days in 2008
height = 60:80;
T = 1:length_year;

% Only the relevant range of NO-profiles are taken

% Since the measurements near 0 can be +/- the instrument noise, the sum
% may be less than 0. However, this is equivalent to 0. 

NOvmr = NO2008(height,:);
NOvmr(NOvmr<0.0)=0.0;

% Sum all altitudes and divide by number of entries to get the NO-column
y1 = sum(NOvmr)/21.0; 

  vmr = y1' ; % Average mixing ratio between 60 and 80 km
 
% One can zoom into a region when there is significant darkness, 
% and where one assumes the NO to be long lived.  
% This will be between day 130 and 220.  
% Ydark=y1(130:220)

%--------------------------------------------------------------------------
% Calculate the NO concentration from VMR, pressure and temperature
%--------------------------------------------------------------------------
load 'pressure2008' % Pressure in [hPa] for each date
load 'temperature2008' % Temperature in [K] for each date
pressure=pressure2008;
temp=temperature2008;

% Make the Pressure-vector & Temperature-vector into a matrix with 
% columns as height and rows as days, this is for convenience later
Pressure = zeros(1,121); 
Temp = zeros(1,121); 
interval = 1:121; 
k = 1;
for i=1:length_year
    Pressure(k,:) = pressure(interval + 121*i -121);
    k = k+1;   
end
k = 1;
for i=1:length_year
    Temp(k,:) = temp(interval + 121*i -121);
    k = k+1;
end
clear k

% Take only pressure and temperature for heights 60 to 80 km, which
% is the range of the NO-vmr data.
Pre = zeros(length_year,21);
Tem = zeros(length_year,21);
for j = 1:length_year
    for i=1:21
    Pre(j,i)= Pressure(j,i+59);
    Tem(j,i)= Temp(j,i+59);
    end
end

% Calculate the concentration of the NO column from vmr, pressure and temp
NOcolumn=zeros(length_year,21);
k=1.38064852*10^(-23); % 
for j=1:length_year
    for i=1:21
        NOcolumn(j,i) = (((NOvmr(i,j))*10^-6)*(Pre(j,i)*100))/(k*Tem(j,i));
        if NOcolumn(j,i)<0
            NOcolumn(j,i) = 0;
        end
    end
end

% NOcolumn = unit is now molucules per m^3
% Perform simpson's rule integration over all heights
for i=1:length_year
    NO(i) = simps(1:21,NOcolumn(i,:)')*1000; 
end

% Integrated column is now expressed in molecules per m^2.
% Express it in molecules per cm^2
NO = NO(:)*10^-4; 

%--------------------------------------------------------------------------
% Plot the data sets for visual reference
%--------------------------------------------------------------------------
 figure(1)
 plot(vmr)
 title('NO volume mixing ratio for 2008')
 xlabel('DOY')
 ylabel('Mixing ratio (parts per million)')
 figure(2)
 plot(NO)
 title('NO-concentration for 2008')
 xlabel('DOY')
 ylabel('Molecules/cm^2')

%Save VMR and [NO] data for later use
save('NO2008','NO')
save('VMR2008','vmr')