%--------------------------------------------------------------------------
% This script takes in a text file containing hourly wind measurements from
% the Sanae research station and creates a matrix of wind amplitude
% components by fitting four-day windows to a mathematical model.
%--------------------------------------------------------------------------
load 'san.txt'

% We want to find how many hours the total measurement period contains, due to
% missing measurements not being filed.
time=datenum(1997,3,3):1/24:datenum(2008,06,28)+1/24;%Find total number of
                                                     %days in time interval
tid = datevec(time);            
NewSan = NaN(length(tid),16);
l_san=length(san);
l_newsan=length(tid); 
counter=1;
%--------------------------------------------------------------------------
% This loop creates an extended array of data with NaNs for each missing
% measurement. It makes fitting more convenient later
%--------------------------------------------------------------------------
    for j=1:l_newsan
        if tid(j,1:4)==san(counter,1:4)
            NewSan(j,:)=san(counter,:);
            counter = counter+1;
        else
            NewSan(j,1:4)=tid(j,1:4);
            
            if counter==length(san)
                break
            end
        end
        
    end
%--------------------------------------------------------------------------
% Vestigial code kept for remembering what the variables were
%--------------------------------------------------------------------------
% San.year = VarName(:,1);   %year 
% San.month = VarName(:,2);  %month
% San.day = VarName(:,3);    %day
% San.hour = VarName(:,4);   %hour
% San.num_avgs = VarName(:,5); % 
% San.frang = VarName(:,6);    % 
% San.rsep = VarName(:,7);     %  
% San.Vx = VarName(:,8); % x-axis (meridional) wind 
% San.Vy = VarName(:,9); % y-axis (zonal) wind
% San.station_lat = VarName(:,10); Station latitude
% San.station_long = VarName(:,11); Station longitude
% San.Vm = VarName(:,12);      %the mean average wind 
% San.Vm_lat = VarName(:,13);  %the mean latitudal wind
% San.Vm_long = VarName(:,14); %the mean longitudal wind
% San.Vx_sdev = VarName(:,15); %the standard deviation of Vx
% San.Vy_sdev = VarName(:,16); %the standard deviation of Vy
 
%--------------------------------------------------------------------------
% Choose relevant part of data set: 94945 = Start of January 1st 2008
% Subtract 36 to align with Day 2.5 (due to the four-day length of the fit)
%--------------------------------------------------------------------------
oi=NewSan(94945-36:length(NewSan),:); % The relevant time period
%--------------------------------------------------------------------------
% This loop removes unwanted measurements, which satisfies the following:
% - Wind speeds over +/- 100 m/s
% - Latitudes deviating from -73.9000
% - Longitudes deviating from -3.4000 
% - Measurements with a standard deviation of 0
%--------------------------------------------------------------------------
  for k=1:length(oi)
      if oi(k,8) >=100
           oi(k,5:16)=NaN;
      end
      if oi(k,8) <=-100
          oi(k,5:16)=NaN;
      end
      if oi(k,9) >=100
           oi(k,5:16)=NaN;
      end
      if oi(k,9) <=-100
          oi(k,5:16)=NaN;
      end
      if oi(k,13)~=-73.9000
           oi(k,5:16)=NaN;
      end
      if oi(k,14)~=-3.4000
           oi(k,5:16)=NaN;
      end
      if oi(k,15)==0
           oi(k,5:16)=NaN;
      end
      if oi(k,16)==0
           oi(k,5:16)=NaN;
      end 
  end
%--------------------------------------------------------------------------
% This loop will calculate the amplitude-matrix for the tides
%--------------------------------------------------------------------------
number_of_windows = floor((median(length(oi)-95,length(oi))-1)/24);
AmplitudeMatrix = zeros(number_of_windows,9);
LowerErrors = zeros(number_of_windows,9);
UpperErrors = zeros(number_of_windows,9);
Errors = zeros(number_of_windows,9);
warning('off','all') 
window = 1; %The initial number of windows
start=1; %The start of the 4-day interval
stop=96; %The end of the 4-day interval
count=0; %Keeps track of which 4-day window 
windows=zeros(number_of_windows,2);

for i=1:number_of_windows   %go though all windows
    y = oi(start:stop,8);   %make the 96-hour window
    %y = NewSan.Vx(:); 
    nans = sum(isnan(y));   %number of NaNs in the window
    nansequence = 0;        %reset the nansequence counter
    exclude = 0;            %reset the exclusion command
    count=count+1;          %the current window-number
    
% Test for 12 NaNs in sequence over 48-hour intervals
for l=1:47
    if isnan(y(l)) && isnan(y(l+1))
        nansequence = nansequence+1;
    else 
        nansequence = 0;
    end
    if nansequence>=12
           exclude=1;
           start;
           break
    end
end
for l=23:71
    if isnan(y(l)) && isnan(y(l+1))
        nansequence = nansequence+1;
    else 
        nansequence = 0;
    end
        if nansequence>=12
            exclude = 1;
            start;
            break
        end
end
for l=47:95
    if isnan(y(l)) && isnan(y(l+1))
        nansequence = nansequence+1;
    else 
        nansequence = 0;
    end
        if nansequence>=12
            exclude = 1;
            start;
            break
        end
end
%Test for regular gaps in data each day (<3 hour gaps)
for l=1:23
    if isnan(y(l)) && isnan(y(l+1))
        nansequence = nansequence+1;
    else 
        nansequence = 0;
    end
        if nansequence>=3
            if isnan(y(l+22))&& isnan(y(l+23))&& isnan(y(l+24))...
                && isnan(y(l+46))&& isnan(y(l+47))&& isnan(y(l+48))...
                && isnan(y(l+70))&& isnan(y(l+71))&& isnan(y(l+72))...
                
            exclude = 1;
            else 
               break 
            end
        end 
end
% Test for less than 48 data points in a 96-hour window
    if nans>48
        exclude = 1;
    end
% Test if the window is to be excluded based on previous tests    
    if exclude==1
        AmplitudeMatrix(i,:) = NaN;
        windows(count,1)=1;
        windows(count,2)=start;       
%If everything is correct, fit the data
    else
        windows(count,1)=0;
        windows(count,2)=start;
        [fitting,gof]=Finalfitwaves((start:stop)',y');
        AmplitudeMatrix(i,:) = (coeffvalues(fitting)');
        
% If the fitted amplitude is negative, take absolute value. Negative value
% represents wind in the other direction relative to the positive values
        if AmplitudeMatrix(i,2)<0
            AmplitudeMatrix(i,2) = abs(AmplitudeMatrix(i,2));
        end
        if AmplitudeMatrix(i,3)<0
            AmplitudeMatrix(i,3) = abs(AmplitudeMatrix(i,3));
        end
        if AmplitudeMatrix(i,4)<0
            AmplitudeMatrix(i,4) = abs(AmplitudeMatrix(i,4));
        end
        if AmplitudeMatrix(i,5)<0
            AmplitudeMatrix(i,5) = abs(AmplitudeMatrix(i,5));
        end
        
        ci = confint(fitting);  %The 95% confidence interval for fitting
        UpperErrors(i,:) = (ci(2,:));
        LowerErrors(i,:) = (ci(1,:));
        Errors(i,:) = (UpperErrors(i,:) - LowerErrors(i,:))/2;
        clear ci
    end
    start = start + 24;   %Jump window-start 24 hours ahead
    stop = stop + 24;     %Jump window-stop 24 hours ahead
end
%--------------------------------------------------------------------------
% The positions in the matrix corresponds to the following:
% 1=average, 2=48 hour wave, 3=24 hour, 4=12 hour, 5=8 hour 
% 6=phi_48, 7=phi_24, 8=phi_12, 9 = phi_8
%--------------------------------------------------------------------------
x24 = AmplitudeMatrix(:,3);  % 24-hour component 
x12 = AmplitudeMatrix(:,4);  % 12-hour component
x8 = AmplitudeMatrix(:,5);   % 8-hour component
x48 = AmplitudeMatrix(:,2);   % 48-hour component
phi24=AmplitudeMatrix(:,3+4);% phase of 24-hour component
phi12=AmplitudeMatrix(:,4+4);% phase of 12-hour component
% Find vector sum of 24-hour and 12-hour components
a = x12.*sin(phi12);
b = x12.*cos(phi12);
a2 = x24.*sin(phi24);
b2 = x24.*cos(phi24);
totx= a + a2;
toty= b + b2;
tot=sqrt(totx.^2+toty.^2);
x12_24=tot;
% Plot 24 and 12 hour components and their phases
figure(1)
subplot(2,2,1)
plot(x24)
title('24 hour amplitudes')
xlabel('DOY')
ylabel('Amplitude [m/s]')
subplot(2,2,2)
plot(x12)
title('12 hour amplitudes')
xlabel('DOY')
ylabel('Amplitude[m/s]')
subplot(2,2,3)
plot(phi24)
title('24 hour phases')
xlabel('DOY')
ylabel('Phase')
subplot(2,2,4)
plot(phi12)
title('12 hour phases')
xlabel('DOY')
ylabel('Phase')

set(gcf, 'PaperPositionMode', 'auto');
print -depsc2 finalPlot1.eps
% Save variables for cross-correlation
save('amplitude12','x12')
save('amplitude24','x24')
save('amplitude12_24','x12_24')
save('amplitude8','x8') 
save('amplitude48','x48') 
